'''
spotidry
'''

__version__ = '0.0.2'
__author__ = 'Mike Boiko'
__email__ = 'mike@boiko.ca'
